@@ -1,5 +1,5 @@
 var folderClosed = new Image(32,32);
-folderClosed.src='/style/Crystal/32/html-menu-treeview/folderClosed.gif';
+folderClosed.src='/style/Crystal/32/html-menu-treeview/folder.png';
 var plusNode = new Image(32,32);
 plusNode.src='/style/Crystal/32/html-menu-treeview/plusNode.gif';
 var lastPlusNode = new Image(32,32);
@@ -9,7 +9,7 @@ clasicPlusNode.src='/style/Crystal/32/html-menu-treeview/clasicPlusNode.gif';
 var clasicLastPlusNode = new Image(32,32);
 clasicLastPlusNode.src='/style/Crystal/32/html-menu-treeview/clasicLastPlusNode.gif';
 var folderManClosed = new Image(32,32);
-folderManClosed.src='/style/Crystal/32/html-menu-treeview/folderManClosed.gif';
+folderManClosed.src='/style/Crystal/32/html-menu-treeview/folder_man.png';
 var folderGray = new Image(32,32);
 folderGray.src='/style/Crystal/32/html-menu-treeview/folderGray.gif';
 var folderGreen = new Image(32,32);
@@ -17,30 +17,30 @@ folderGreen.src='/style/Crystal/32/html-menu-treeview/folderGreen.gif';
 var folderViolet = new Image(32,32);
 folderViolet.src='/style/Crystal/32/html-menu-treeview/folderViolet.gif';
 var folderYellowClosed = new Image(32,32);
-folderYellowClosed.src='/style/Crystal/32/html-menu-treeview/folderYellowClosed.gif';
+folderYellowClosed.src='/style/Crystal/32/html-menu-treeview/folder_yellow.png';
 var folderOrangeClosed = new Image(32,32);
-folderOrangeClosed.src='/style/Crystal/32/html-menu-treeview/folderOrangeClosed.gif';
+folderOrangeClosed.src='/style/Crystal/32/html-menu-treeview/folder_orange.png';
 var folderManClosed = new Image(32,32);
-folderManClosed.src='/style/Crystal/32/html-menu-treeview/folderManClosed.gif';
+folderManClosed.src='/style/Crystal/32/html-menu-treeview/folder_man.png';
 var folderHtmlClosed = new Image(32,32);
-folderHtmlClosed.src='/style/Crystal/32/html-menu-treeview/folderHtmlClosed.gif';
+folderHtmlClosed.src='/style/Crystal/32/html-menu-treeview/folder_html.png';
 var folderFavoriteClosed = new Image(32,32);
-folderFavoriteClosed.src='/style/Crystal/32/html-menu-treeview/folderFavoriteClosed.gif';
+folderFavoriteClosed.src='/style/Crystal/32/html-menu-treeview/folder_favorite.png';
 var folderTextClosed = new Image(32,32);
-folderTextClosed.src='/style/Crystal/32/html-menu-treeview/folderTextClosed.gif';
+folderTextClosed.src='/style/Crystal/32/html-menu-treeview/folder_text.png';
 var folderLockedClosed = new Image(32,32);
-folderLockedClosed.src='/style/Crystal/32/html-menu-treeview/folderLockedClosed.gif';
+folderLockedClosed.src='/style/Crystal/32/html-menu-treeview/folder_locked.png';
 var folderCrystalClosed = new Image(32,32);
-folderCrystalClosed.src='/style/Crystal/32/html-menu-treeview/folderCrystalClosed.gif';
+folderCrystalClosed.src='/style/Crystal/32/html-menu-treeview/folder_crystal.png';
 var folderVideoClosed = new Image(32,32);
-folderVideoClosed.src='/style/Crystal/32/html-menu-treeview/folderVideoClosed.gif';
+folderVideoClosed.src='/style/Crystal/32/html-menu-treeview/folder_video.png';
 var folderPrintClosed = new Image(32,32);
-folderPrintClosed.src='/style/Crystal/32/html-menu-treeview/folderPrintClosed.gif';
+folderPrintClosed.src='/style/Crystal/32/html-menu-treeview/folder_print.png';
 var folderImageClosed = new Image(32,32);
-folderImageClosed.src='/style/Crystal/32/html-menu-treeview/folderImageClosed.gif';
+folderImageClosed.src='/style/Crystal/32/html-menu-treeview/folder_image.png';
 var folderSoundClosed = new Image(32,32);
-folderSoundClosed.src='/style/Crystal/32/html-menu-treeview/folderSoundClosed.gif';
+folderSoundClosed.src='/style/Crystal/32/html-menu-treeview/folder_sound.png';
 var folderImportantClosed = new Image(32,32);
-folderImportantClosed.src='/style/Crystal/32/html-menu-treeview/folderImportantClosed.gif';
+folderImportantClosed.src='/style/Crystal/32/html-menu-treeview/folder_important.png';
 var folderTarClosed = new Image(32,32);
-folderTarClosed.src='/style/Crystal/32/html-menu-treeview/folderTarClosed.gif';
+folderTarClosed.src='/style/Crystal/32/html-menu-treeview/folder_tar.png';
